#include <SPI.h>                  // WiFi
#include <WiFiNINA.h>             // WiFi
#include <ArduinoHttpClient.h>    // Sending HTTP data

#include "arduino_secrets.h" 
///////please enter your sensitive data in the Secret tab/arduino_secrets.h
char ssid[] = SECRET_SSID;        // your network SSID (name)
char pass[] = SECRET_PASS;    // your network password (use for WPA)

int status = WL_IDLE_STATUS;

void setup() {
  //Initialize serial and wait for port to open:
  Serial.begin(9600);
  while (!Serial) ; // wait for Serial to be ready before going on

  Serial.println("Starting WiFi test");
  
  // check for the WiFi module:
  if (WiFi.status() == WL_NO_MODULE) {
    Serial.println("Communication with WiFi module failed - halting!");
    // don't continue
    while (true);
  }

  // attempt to connect to WiFi network:
  while (status != WL_CONNECTED) {
    Serial.print("Attempting to connect to SSID: ");
    Serial.println(ssid);
    status = WiFi.begin(ssid, pass);
    delay(1000);
  }
  Serial.println("\nConnected to WiFi");
  printWiFiStatus();
  testHttpConnection();
  testSecureHttpConnection();
  Serial.println("done with wifi tests!");
}

void loop() {

}

void printWiFiStatus() {
  // print the SSID of the network you're attached to:
  Serial.print("SSID: ");
  Serial.println(WiFi.SSID());

  // print your board's IP address:
  IPAddress ip = WiFi.localIP();
  Serial.print("Local IP Address: ");
  Serial.println(ip);

  // print the received signal strength:
  long rssi = WiFi.RSSI();
  Serial.print("signal strength (RSSI):");
  Serial.print(rssi);
  Serial.println(" dBm");
}

void testHttpConnection() {
  Serial.println("\nTesting http connection");
  char server[] = "api.ipify.org";
  int port = 80; // port 80 is default for HTTP
  String path = "/";
  WiFiClient wificlient;
  HttpClient httpclient = HttpClient(wificlient, server, port);
  httpclient.get(path);
  int statusCode = httpclient.responseStatusCode();
  String response = httpclient.responseBody();
  Serial.print("Status code: ");
  Serial.println(statusCode);
  Serial.print("Response: ");
  Serial.println(response);
  if (!wificlient.connected()) {
    wificlient.stop();
  }
}

void testSecureHttpConnection() {
  Serial.println("\nTesting secure http connection");
  char server[] = "200b.mit.edu";
  int port = 443; // 443 for HTTPS
  String path = "/apps/health/test/";
  WiFiSSLClient wificlient;
  HttpClient httpclient = HttpClient(wificlient, server, port);
  httpclient.get(path);
  int statusCode = httpclient.responseStatusCode();
  String response = httpclient.responseBody();
  Serial.print("Status code: ");
  Serial.println(statusCode);
  Serial.print("Response: ");
  Serial.println(response);
  if (!wificlient.connected()) {
    wificlient.stop();
  }
}
